@@ -3,8 +3,8 @@
 /**
  * @file plugins/importexport/onix30/filter/MonographONIX30XmlFilter.inc.php
  *
- * Copyright (c) 2014-2021 Simon Fraser University
- * Copyright (c) 2000-2021 John Willinsky
+ * Copyright (c) 2014-2024 Simon Fraser University
+ * Copyright (c) 2000-2024 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class MonographONIX30XmlFilter
@@ -29,7 +29,6 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		parent::__construct($filterGroup);
 	}
 
-
 	//
 	// Implement template methods from PersistableFilter
 	//
@@ -121,7 +120,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		$senderNode->appendChild($senderIdentifierNode);
 
 		// Assemble SenderName element.
-		$senderNode->appendChild($this->_buildTextNode($doc, 'SenderName', $context->getLocalizedName()));
+		$senderNode->appendChild($this->_buildTextNode($doc, 'SenderName', $context->getName($context->getPrimaryLocale())));
 		$senderNode->appendChild($this->_buildTextNode($doc, 'ContactName', $context->getContactName()));
 		$senderNode->appendChild($this->_buildTextNode($doc, 'EmailAddress', $context->getContactEmail()));
 
@@ -155,18 +154,31 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 		$identifierGiven = false;
 
-		$identificationCodes = $publicationFormat->getIdentificationCodes();
+		$publication = $submission->getCurrentPublication();
+		$publicationFormats = $publication->getData('publicationFormats');
 
-		while ($code = $identificationCodes->next()) {
-			$productIdentifierNode = $doc->createElementNS($deployment->getNamespace(), 'ProductIdentifier');
-			$productIdentifierNode->appendChild($this->_buildTextNode($doc, 'ProductIDType', $code->getCode())); // GTIN-13 (ISBN-13 as GTIN)
-			$productIdentifierNode->appendChild($this->_buildTextNode($doc, 'IDValue', $code->getValue()));
-			$productNode->appendChild($productIdentifierNode);
+		// Collect identifiers for all publication formats to connect related products (see Related Material)
+		$identificationCodes = [];
+		foreach ($publicationFormats as $pubFormat) {
+			$pubIdentificationCodes = $pubFormat->getIdentificationCodes();
+			$pubId = $pubFormat->getId();
+			while ($code = $pubIdentificationCodes->next()) {
+				$identificationCodes[$pubId][$code->getCode()] = $code->getValue();
+			}
+		}
 
-			unset($productIdentifierNode);
-			unset($code);
+		if (array_key_exists($publicationFormat->getId(), $identificationCodes)) {
+			foreach ($identificationCodes[$publicationFormat->getId()] as $code => $value) {
+				$productIdentifierNode = $doc->createElementNS($deployment->getNamespace(), 'ProductIdentifier');
+				$productIdentifierNode->appendChild($this->_buildTextNode($doc, 'ProductIDType', $code));
+				$productIdentifierNode->appendChild($this->_buildTextNode($doc, 'IDValue', $value));
+				$productNode->appendChild($productIdentifierNode);
 
-			$identifierGiven = true;
+				unset($productIdentifierNode);
+				unset($code);
+
+				$identifierGiven = true;
+			}
 		}
 
 		// Deal with the possibility of a DOI pubId from the plugin.
@@ -247,14 +259,14 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 		/* --- License information --- */
 
-		$publication = $submission->getCurrentPublication();
+		$pubLocale = $publication->getData('locale');
 
 		if ($publication->isCCLicense()) {
-			AppLocale::requireComponents(LOCALE_COMPONENT_PKP_SUBMISSION); // For CC License Names
+			AppLocale::requireComponents(LOCALE_COMPONENT_PKP_SUBMISSION, $pubLocale); // For CC License Names
 			$licenseOpts = Application::getCCLicenseOptions();
 			$licenseUrl = $publication->getData('licenseUrl');
 			if (array_key_exists($licenseUrl, $licenseOpts)) {
-				$licenseName = (__($licenseOpts[$licenseUrl], [], $publication->getData('locale')));
+				$licenseName = (__($licenseOpts[$licenseUrl], [], $pubLocale));
 
 				$epubLicenseNode = $doc->createElementNS($deployment->getNamespace(), 'EpubLicense');
 				$descDetailNode->appendChild($epubLicenseNode);
@@ -291,19 +303,22 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 				$titleElementNode->appendChild($this->_buildTextNode($doc, 'PartNumber', $submission->getCurrentPublication()->getData('seriesPosition')));
 			}
 
-			if ($series->getLocalizedPrefix() == '' || $series->getLocalizedTitle(false) == '') {
-				$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleText', trim(join(' ', array($series->getLocalizedPrefix(), $series->getLocalizedTitle(false))))));
-			} else {
-				if ($series->getLocalizedPrefix() != '') {
-					$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitlePrefix', $series->getLocalizedPrefix()));
-				} else {
-					$titleElementNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoPrefix'));
-				}
-				$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleWithoutPrefix', $series->getLocalizedTitle(false)));
+			$seriesLocale = $pubLocale;
+			// If the series title doesn't exist in the submission locale, use the press locale
+			if ($series->getTitle($seriesLocale, false) == '') {
+				$seriesLocale = $context->getPrimaryLocale();
 			}
 
-			if ($series->getLocalizedSubtitle() != '') {
-				$titleElementNode->appendChild($this->_buildTextNode($doc, 'Subtitle', $series->getLocalizedSubtitle()));
+			if ($series->getPrefix($seriesLocale) != '') {
+				$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitlePrefix', $series->getPrefix($seriesLocale)));
+			} else {
+				$titleElementNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoPrefix'));
+			}
+
+			$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleWithoutPrefix', $series->getTitle($seriesLocale, false)));
+
+			if ($series->getSubtitle($seriesLocale) != '') {
+				$titleElementNode->appendChild($this->_buildTextNode($doc, 'Subtitle', $series->getSubtitle($seriesLocale)));
 			}
 		} else {
 			$seriesCollectionNode = $doc->createElementNS($deployment->getNamespace(), 'NoCollection');
@@ -322,20 +337,16 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 		$productTitleDetailNode->appendChild($titleElementNode);
 
-		if (!$publication->getLocalizedData('prefix') || !$publication->getLocalizedData('title')) {
-			$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleText', trim($publication->getLocalizedData('prefix') ?? $publication->getLocalizedTitle())));
+		if ($publication->getData('prefix', $pubLocale)) {
+			$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitlePrefix', $publication->getData('prefix', $pubLocale)));
 		} else {
-			if ($publication->getLocalizedData('prefix')) {
-				$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitlePrefix', $publication->getLocalizedData('prefix')));
-			} else {
-				$titleElementNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoPrefix'));
-			}
-
-			$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleWithoutPrefix', $publication->getLocalizedTitle()));
+			$titleElementNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoPrefix'));
 		}
 
-		if ($publication->getData('subtitle', $publication->getData('locale'))) {
-			$titleElementNode->appendChild($this->_buildTextNode($doc, 'Subtitle', $publication->getData('subtitle', $publication->getData('locale'))));
+		$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleWithoutPrefix', $publication->getData('title', $pubLocale)));
+
+		if ($publication->getData('subtitle', $pubLocale)) {
+			$titleElementNode->appendChild($this->_buildTextNode($doc, 'Subtitle', $publication->getData('subtitle', $pubLocale)));
 		}
 
 		/* --- Contributor information --- */
@@ -349,23 +360,29 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$userGroupDao = DAORegistry::getDAO('UserGroupDAO'); /* @var $userGroupDao UserGroupDAO */
 			$userGroup = $userGroupDao->getById($author->getUserGroupId(), $submission->getContextId());
 
-			$userGroupOnixMap = array('default.groups.name.author' => 'A01', 'default.groups.name.volumeEditor' => 'B01', 'default.groups.name.chapterAuthor' => 'A01', 'default.groups.name.translator' => 'B06', 'default.groups.name.editor' => 'B21'); // From List17, ContributorRole types.
+			$userGroupOnixMap = [
+				'default.groups.name.author' => 'A01',
+				'default.groups.name.volumeEditor' => 'B01',
+				'default.groups.name.chapterAuthor' => 'A01',
+				'default.groups.name.translator' => 'B06',
+				'default.groups.name.editor' => 'B21',
+			]; // From List17, ContributorRole types.
 
 			$nameKey = $userGroup->getData('nameLocaleKey');
 			$role = array_key_exists($nameKey, $userGroupOnixMap) ? $userGroupOnixMap[$nameKey] : 'Z99'; // Z99 - unknown contributor type.
 
 			$contributorNode->appendChild($this->_buildTextNode($doc, 'ContributorRole', $role));
-			$contributorNode->appendChild($this->_buildTextNode($doc, 'PersonName', $author->getFullName(false)));
-			$contributorNode->appendChild($this->_buildTextNode($doc, 'PersonNameInverted', $author->getFullName(false, true)));
-			$contributorNode->appendChild($this->_buildTextNode($doc, 'NamesBeforeKey', $author->getLocalizedGivenName()));
-			if ($author->getLocalizedFamilyName() != '') {
-				$contributorNode->appendChild($this->_buildTextNode($doc, 'KeyNames', $author->getLocalizedFamilyName()));
+			$contributorNode->appendChild($this->_buildTextNode($doc, 'PersonName', $author->getFullName(false, false, null, $pubLocale)));
+			$contributorNode->appendChild($this->_buildTextNode($doc, 'PersonNameInverted', $author->getFullName(false, true, null, $pubLocale)));
+			$contributorNode->appendChild($this->_buildTextNode($doc, 'NamesBeforeKey', $author->getGivenName($pubLocale)));
+			if ($author->getFamilyName($pubLocale) != '') {
+				$contributorNode->appendChild($this->_buildTextNode($doc, 'KeyNames', $author->getFamilyName($pubLocale)));
 			} else {
-				$contributorNode->appendChild($this->_buildTextNode($doc, 'KeyNames', $author->getFullName(false)));
+				$contributorNode->appendChild($this->_buildTextNode($doc, 'KeyNames', $author->getFullName(false, false, null, $pubLocale)));
 			}
 
-			if ($author->getLocalizedBiography() != '') {
-				$contributorNode->appendChild($this->_buildTextNode($doc, 'BiographicalNote', $author->getLocalizedBiography()));
+			if ($author->getBiography($pubLocale) != '') {
+				$contributorNode->appendChild($this->_buildTextNode($doc, 'BiographicalNote', $author->getBiography($pubLocale)));
 			}
 
 			if ($author->getCountry() != '') {
@@ -389,32 +406,20 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$descDetailNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoContributor')); // empty state of fact.
 		}
 
-		/* --- Add Language elements --- */
+		/* --- Add Language element --- */
 
-		$submissionLanguageDao = DAORegistry::getDAO('SubmissionLanguageDAO'); /* @var $submissionLanguageDao SubmissionLanguageDAO */
-		$allLanguages = $submissionLanguageDao->getLanguages($publication->getId(), array_keys(AppLocale::getSupportedFormLocales()));
-		$uniqueLanguages = array();
-		foreach ($allLanguages as $locale => $languages) {
-			$uniqueLanguages = array_merge($uniqueLanguages, $languages);
-		}
-
-		foreach ($uniqueLanguages as $language) {
+		if ($onixCodelistItemDao->codeExistsInList(AppLocale::get3LetterIsoFromLocale($pubLocale), 'List74')) {
 			$languageNode = $doc->createElementNS($deployment->getNamespace(), 'Language');
-
 			$languageNode->appendChild($this->_buildTextNode($doc, 'LanguageRole', '01'));
-			$onixLanguageCode = $onixCodelistItemDao->getCodeFromValue($language, 'List74');
-			if ($onixLanguageCode != '') {
-				$languageNode->appendChild($this->_buildTextNode($doc, 'LanguageCode', $onixLanguageCode));
-				$descDetailNode->appendChild($languageNode);
-			}
-			unset($languageNode);
+			$languageNode->appendChild($this->_buildTextNode($doc, 'LanguageCode', AppLocale::get3LetterIsoFromLocale($pubLocale)));
+			$descDetailNode->appendChild($languageNode);
 		}
 
-		/* --- add Extents for 00 (main content), 04 (back matter), 08 for digital works ---*/
+		/* --- add Extents for 03 (front matter), 04 (back matter), 22 for digital works ---*/
 
 		if ($publicationFormat->getFrontMatter() > 0) {
 			// 03 - Pages
-			$extentNode = $this->_createExtentNode($doc, $deployment, '00', $publicationFormat->getFrontMatter(), '03');
+			$extentNode = $this->_createExtentNode($doc, $deployment, '03', $publicationFormat->getFrontMatter(), '03');
 			$descDetailNode->appendChild($extentNode);
 			unset($extentNode);
 		}
@@ -427,7 +432,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 		if (!$publicationFormat->getPhysicalFormat()) { // EBooks and digital content have extent information about file sizes
 			$fileSize = $publicationFormat->getFileSize() ? $publicationFormat->getFileSize() : $publicationFormat->getCalculatedFileSize();
-			$extentNode = $this->_createExtentNode($doc, $deployment, '08', $fileSize, '05');
+			$extentNode = $this->_createExtentNode($doc, $deployment, '22', $fileSize, '19'); // 22 -> Filesize, 19 -> Mbytes
 			$descDetailNode->appendChild($extentNode);
 			unset($extentNode);
 		}
@@ -442,13 +447,13 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeIdentifier', '12')); // 12 is BIC subject category code list.
 			$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeVersion', '2')); // Version 2 of ^^
 
-			$allSubjects = ($publication->getData('subjects')[$publication->getData('locale')]);
+			$allSubjects = ($publication->getData('subjects')[$pubLocale]);
 			$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectCode', trim(join(', ', $allSubjects))));
 			$descDetailNode->appendChild($subjectNode);
 		}
 
 		if ($publication->getData('keywords')) {
-			$allKeywords = ($publication->getData('keywords')[$publication->getData('locale')]);
+			$allKeywords = ($publication->getData('keywords')[$pubLocale]);
 			$keywordNode = $doc->createElementNS($deployment->getNamespace(), 'Subject');
 			$keywordNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeIdentifier', '20')); // Keywords
 			$keywordNode->appendChild($this->_buildTextNode($doc, 'SubjectHeadingText', trim(join(', ', $allKeywords))));
@@ -493,7 +498,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		$collateralDetailNode = $doc->createElementNS($deployment->getNamespace(), 'CollateralDetail');
 		$productNode->appendChild($collateralDetailNode);
 
-		$abstract = strip_tags($publication->getLocalizedData('abstract'));
+		$abstract = strip_tags($publication->getData('abstract', $pubLocale));
 
 		$textContentNode = $doc->createElementNS($deployment->getNamespace(), 'TextContent');
 		$collateralDetailNode->appendChild($textContentNode);
@@ -517,7 +522,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		$resourceVersionNode = $doc->createElementNS($deployment->getNamespace(), 'ResourceVersion');
 		$supportingResourceNode->appendChild($resourceVersionNode);
 		$resourceVersionNode->appendChild($this->_buildTextNode($doc, 'ResourceForm', '01')); // Linkable resource
-		$resourceVersionNode->appendChild($this->_buildTextNode($doc, 'ResourceLink', $publication->getLocalizedCoverImageUrl($context->getId(), $publication->getData('locale'))));
+		$resourceVersionNode->appendChild($this->_buildTextNode($doc, 'ResourceLink', $publication->getCoverImageUrl($context->getId(), $pubLocale)));
 
 		/* --- Publishing Detail --- */
 
@@ -624,6 +629,29 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$publishingDetailNode->appendChild($this->_buildTextNode($doc, 'ROWSalesRightsType', $salesRightsROW->getType()));
 		}
 
+		/* --- Related Material --- */
+
+		unset($identificationCodes[$publicationFormat->getId()]);  // remove identifiers for the current publication format
+
+		if (count($identificationCodes) > 0) {
+			$relatedMaterialNode = $doc->createElementNS($deployment->getNamespace(), 'RelatedMaterial');
+
+			$relatedProductNode = $doc->createElementNS($deployment->getNamespace(), 'RelatedProduct');
+			$relatedProductNode->appendChild($this->_buildTextNode($doc, 'ProductRelationCode', '06')); // alternative format
+
+			foreach ($identificationCodes as $pubId => $idCodes) {
+				foreach ($idCodes as $code => $value) {
+					$productIdentifierNode = $doc->createElementNS($deployment->getNamespace(), 'ProductIdentifier');
+					$productIdentifierNode->appendChild($this->_buildTextNode($doc, 'ProductIDType', $code));
+					$productIdentifierNode->appendChild($this->_buildTextNode($doc, 'IDValue', $value));
+					$relatedProductNode->appendChild($productIdentifierNode);
+					unset($productIdentifierNode);
+				}
+			}
+			$relatedMaterialNode->appendChild($relatedProductNode);
+			$productNode->appendChild($relatedMaterialNode);
+		}
+
 		/* --- Product Supply.  We create one of these per defined Market. --- */
 
 		$representativeDao = DAORegistry::getDAO('RepresentativeDAO'); /* @var $representativeDao RepresentativeDAO */
@@ -707,15 +735,16 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$supplyDetailNode = $doc->createElementNS($deployment->getNamespace(), 'SupplyDetail');
 			$productSupplyNode->appendChild($supplyDetailNode);
 
+			$supplierNode = $doc->createElementNS($deployment->getNamespace(), 'Supplier');
+			$supplyDetailNode->appendChild($supplierNode);
 			if (isset($supplier)) {
-				$supplierNode = $doc->createElementNS($deployment->getNamespace(), 'Supplier');
-				$supplyDetailNode->appendChild($supplierNode);
 
 				$supplierNode->appendChild($this->_buildTextNode($doc, 'SupplierRole', $supplier->getRole()));
 				$supplierNode->appendChild($this->_buildTextNode($doc, 'SupplierName', $supplier->getName()));
 				if ($supplier->getPhone()) {
 					$supplierNode->appendChild($this->_buildTextNode($doc, 'TelephoneNumber', $supplier->getPhone()));
 				}
+
 				if ($supplier->getEmail()) {
 					$supplierNode->appendChild($this->_buildTextNode($doc, 'EmailAddress', $supplier->getEmail()));
 				}
@@ -735,12 +764,8 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 				$supplierWebsiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteRole', '29')); // 29 -> Web page for full content
 				$supplierWebsiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteLink', $request->url($context->getPath(), 'catalog', 'book', $submissionBestId)));
-				unset($supplierNode);
-				unset($supplierWebsiteNode);
 
 			} else { // No suppliers specified, use the Press settings instead.
-				$supplierNode = $doc->createElementNS($deployment->getNamespace(), 'Supplier');
-				$supplyDetailNode->appendChild($supplierNode);
 
 				$supplierNode->appendChild($this->_buildTextNode($doc, 'SupplierRole', '09')); // Publisher supplying to end customers
 				$supplierNode->appendChild($this->_buildTextNode($doc, 'SupplierName', $context->getData('publisher')));
@@ -755,9 +780,9 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 				$supplierWebsiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteRole', '18')); // 18 -> Public website
 				$supplierWebsiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteLink', $request->url($context->getPath())));
 
-				unset($supplierNode);
-				unset($supplierWebsiteNode);
 			}
+			unset($supplierNode);
+			unset($supplierWebsiteNode);
 
 			if ($publicationFormat->getReturnableIndicatorCode() != '') {
 				$returnsNode = $doc->createElementNS($deployment->getNamespace(), 'ReturnsConditions');
@@ -892,5 +917,3 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		return $node;
 	}
 }
-
-
